==> scons-4.1.0.post1-py38haa244fe_0.tar.bz2: info/test/run_test.py <==
#  tests for scons-4.1.0.post1-py38haa244fe_0 (this is a generated file);
print('===== testing package: scons-4.1.0.post1-py38haa244fe_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
"""
Check that scons --help is working.

We need this manual check because the original 'scons.bat' from
scons win-py36 3.0.0 package would crash the interpreter (see #2).

Unfortunately, calling `scons.bat --help` will crash the interpreter
and surprisingly still return 0 exit code, which would make the
build succeed.

This script then calls `scons --help` and ensures the correct
output is returned.
"""
import subprocess
import sys

PY3 = sys.version_info[0] == 3

output = subprocess.check_output('scons --help', shell=True)
if PY3:
    output = output.decode('UTF-8')
assert 'SCons Options:' in output
print('SCons is correctly installed')
#  --- run_test.py (end) ---

print('===== scons-4.1.0.post1-py38haa244fe_0 OK =====');
print("import: 'SCons'")
import SCons

print("import: 'SCons.Node'")
import SCons.Node

print("import: 'SCons.Platform'")
import SCons.Platform

print("import: 'SCons.Scanner'")
import SCons.Scanner

print("import: 'SCons.Script'")
import SCons.Script

print("import: 'SCons.Tool'")
import SCons.Tool

print("import: 'SCons.Tool.MSCommon'")
import SCons.Tool.MSCommon

print("import: 'SCons.Tool.docbook'")
import SCons.Tool.docbook

print("import: 'SCons.Tool.packaging'")
import SCons.Tool.packaging

print("import: 'SCons.Variables'")
import SCons.Variables

print("import: 'SCons.compat'")
import SCons.compat

==> scons-4.2.0-py38haa244fe_0.tar.bz2: info/test/run_test.py <==
#  tests for scons-4.2.0-py38haa244fe_0 (this is a generated file);
print('===== testing package: scons-4.2.0-py38haa244fe_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
"""
Check that scons --help is working.

We need this manual check because the original 'scons.bat' from
scons win-py36 3.0.0 package would crash the interpreter (see #2).

Unfortunately, calling `scons.bat --help` will crash the interpreter
and surprisingly still return 0 exit code, which would make the
build succeed.

This script then calls `scons --help` and ensures the correct
output is returned.
"""
import subprocess
import sys

PY3 = sys.version_info[0] == 3

output = subprocess.check_output('scons --help', shell=True)
if PY3:
    output = output.decode('UTF-8')
assert 'SCons Options:' in output
print('SCons is correctly installed')
#  --- run_test.py (end) ---

print('===== scons-4.2.0-py38haa244fe_0 OK =====');
print("import: 'SCons'")
import SCons

print("import: 'SCons.Node'")
import SCons.Node

print("import: 'SCons.Platform'")
import SCons.Platform

print("import: 'SCons.Scanner'")
import SCons.Scanner

print("import: 'SCons.Script'")
import SCons.Script

print("import: 'SCons.Tool'")
import SCons.Tool

print("import: 'SCons.Tool.MSCommon'")
import SCons.Tool.MSCommon

print("import: 'SCons.Tool.docbook'")
import SCons.Tool.docbook

print("import: 'SCons.Tool.packaging'")
import SCons.Tool.packaging

print("import: 'SCons.Variables'")
import SCons.Variables

print("import: 'SCons.compat'")
import SCons.compat
